==> haskell-string-interpolate-0.3.4.0-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-L3A8dPESgaj35YtlRCcSdH
key:                  string-interpolate-0.3.4.0-L3A8dPESgaj35YtlRCcSdH
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  72852985255aa8a9d4e0651a3cd31d3a
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-L3A8dPESgaj35YtlRCcSdH
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    haskell-src-exts-1.23.1-EQsaf5CMOxi6fZopto4Klc
    haskell-src-meta-0.8.12-Fe5kGltKJxeIZkKj5WAOn4
    split-0.2.5-L5qB0eGVSdY6HJmwsU4RMl template-haskell-2.18.0.0
    text-1.2.5.0 text-conversions-0.3.1.1-Ds2ki1S0HMMH7HuRG1aZYm
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-interpolate-0.3.4.0-57.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-3pPvg9FpEjl2JaQftnXpLc
key:                  string-interpolate-0.3.4.0-3pPvg9FpEjl2JaQftnXpLc
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  c2165dbe2584039feca7285bd301b5d5
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-3pPvg9FpEjl2JaQftnXpLc
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-exts-1.23.1-9EvhCcP56BSBlDpgj0lBcI
    haskell-src-meta-0.8.15-2rjn8Wn2LvaEalb4n30kWZ
    split-0.2.5-2HeD4Nuqed4MnDSfwehTU template-haskell-2.19.0.0
    text-2.0.2 text-conversions-0.3.1.1-C5BzOlVJGSXDETl1pymqXg
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
